@@ -5,7 +5,7 @@ from pydantic import ValidationError
 from .main import create_model, validate_model
 
 
-def post_init(self):
+def _pydantic_post_init(self):
     d = validate_model(self.__pydantic_model__, self.__dict__)
     object.__setattr__(self, '__dict__', d)
     object.__setattr__(self, '__initialised__', True)
@@ -26,7 +26,9 @@ def setattr_validate_assignment(self, name, value):
 
 def _process_class(_cls, init, repr, eq, order, unsafe_hash, frozen, validate_assignment):
     post_init_original = getattr(_cls, '__post_init__', None)
-    _cls.__post_init__ = post_init
+    if post_init_original and post_init_original.__name__ == '_pydantic_post_init':
+        post_init_original = None
+    _cls.__post_init__ = _pydantic_post_init
     cls = dataclasses._process_class(_cls, init, repr, eq, order, unsafe_hash, frozen)
 
     fields = {name: (field.type, field.default) for name, field in cls.__dataclass_fields__.items()}
@@ -39,8 +41,9 @@ def _process_class(_cls, init, repr, eq, order, unsafe_hash, frozen, validate_as
     return cls
 
 
-def dataclass(_cls=None, *, init=True, repr=True, eq=True, order=False, unsafe_hash=False, frozen=False,
-              validate_assignment=False):
+def dataclass(
+    _cls=None, *, init=True, repr=True, eq=True, order=False, unsafe_hash=False, frozen=False, validate_assignment=False
+):
     """
     Like the python standard lib dataclasses but with type validation.
 
