@@ -28,10 +28,7 @@ class BaseSettings(BaseModel):
     """
 
     def __init__(self, **values):
-        values = {
-            **self._substitute_environ(),
-            **values,
-        }
+        values = {**self._substitute_environ(), **values}
         super().__init__(**values)
 
     def _substitute_environ(self):
@@ -40,7 +37,7 @@ class BaseSettings(BaseModel):
         """
         d = {}
         for field in self.__fields__.values():
-            if field.alt_alias:
+            if field.has_alias:
                 env_name = field.alias
             else:
                 env_name = self.__config__.env_prefix + field.name.upper()
