@@ -45,9 +45,9 @@ class BaseConfig:
 
 def inherit_config(self_config: Type[BaseConfig], parent_config: Type[BaseConfig]) -> Type[BaseConfig]:
     if not self_config:
-        base_classes = parent_config,
+        base_classes = (parent_config,)
     elif self_config == parent_config:
-        base_classes = self_config,
+        base_classes = (self_config,)
     else:
         base_classes = self_config, parent_config
     return type('Config', base_classes, {})
@@ -69,12 +69,20 @@ class ValidatorGroup:
             return (specific_validators or []) + (wildcard_validators or [])
 
     def check_for_unused(self):
-        unused_validators = set(chain(*[(v.func.__name__ for v in self.validators[f] if v.check_fields)
-                                        for f in (self.validators.keys() - self.used_validators)]))
+        unused_validators = set(
+            chain(
+                *[
+                    (v.func.__name__ for v in self.validators[f] if v.check_fields)
+                    for f in (self.validators.keys() - self.used_validators)
+                ]
+            )
+        )
         if unused_validators:
             fn = ', '.join(unused_validators)
-            raise ConfigError(f"Validators defined with incorrect fields: {fn} "
-                              f"(use check_fields=False if you're inheriting from the model and intended this)")
+            raise ConfigError(
+                f"Validators defined with incorrect fields: {fn} "
+                f"(use check_fields=False if you're inheriting from the model and intended this)"
+            )
 
 
 def _extract_validators(namespace):
@@ -146,7 +154,7 @@ class MetaModel(ABCMeta):
             '__validators__': vg.validators,
             '_schema_cache': {},
             '_json_encoder': staticmethod(json_encoder),
-            **{n: v for n, v in namespace.items() if n not in fields}
+            **{n: v for n, v in namespace.items() if n not in fields},
         }
         return super().__new__(mcs, name, bases, new_namespace)
 
@@ -160,7 +168,7 @@ class BaseModel(metaclass=MetaModel):
     __validators__ = {}
 
     Config = BaseConfig
-    __slots__ = '__values__',
+    __slots__ = ('__values__',)
 
     def __init__(self, **data):
         self.__setstate__(self._process_values(data))
@@ -191,7 +199,7 @@ class BaseModel(metaclass=MetaModel):
     def __setstate__(self, state):
         object.__setattr__(self, '__values__', state)
 
-    def dict(self, *, include: Set[str]=None, exclude: Set[str]=set(), by_alias: bool = False) -> Dict[str, Any]:
+    def dict(self, *, include: Set[str] = None, exclude: Set[str] = set(), by_alias: bool = False) -> Dict[str, Any]:
         """
         Generate a dictionary representation of the model, optionally specifying which fields to include or exclude.
         """
@@ -210,8 +218,15 @@ class BaseModel(metaclass=MetaModel):
 
         return lambda _, key: key
 
-    def json(self, *, include: Set[str]=None, exclude: Set[str]=set(), by_alias: bool = False,
-             encoder=None, **dumps_kwargs) -> str:
+    def json(
+        self,
+        *,
+        include: Set[str] = None,
+        exclude: Set[str] = set(),
+        by_alias: bool = False,
+        encoder=None,
+        **dumps_kwargs,
+    ) -> str:
         """
         Generate a JSON representation of the model, `include` and `exclude` arguments as per `dict()`.
 
@@ -219,7 +234,8 @@ class BaseModel(metaclass=MetaModel):
         """
         return json.dumps(
             self.dict(include=include, exclude=exclude, by_alias=by_alias),
-            default=encoder or self._json_encoder, **dumps_kwargs
+            default=encoder or self._json_encoder,
+            **dumps_kwargs,
         )
 
     @classmethod
@@ -230,24 +246,33 @@ class BaseModel(metaclass=MetaModel):
         return cls(**obj)
 
     @classmethod
-    def parse_raw(cls, b: StrBytes, *,
-                  content_type: str=None,
-                  encoding: str='utf8',
-                  proto: Protocol=None,
-                  allow_pickle: bool=False):
+    def parse_raw(
+        cls,
+        b: StrBytes,
+        *,
+        content_type: str = None,
+        encoding: str = 'utf8',
+        proto: Protocol = None,
+        allow_pickle: bool = False,
+    ):
         try:
-            obj = load_str_bytes(b, proto=proto, content_type=content_type, encoding=encoding,
-                                 allow_pickle=allow_pickle)
+            obj = load_str_bytes(
+                b, proto=proto, content_type=content_type, encoding=encoding, allow_pickle=allow_pickle
+            )
         except (ValueError, TypeError, UnicodeDecodeError) as e:
             raise ValidationError([ErrorWrapper(e, loc='__obj__')])
         return cls.parse_obj(obj)
 
     @classmethod
-    def parse_file(cls, path: Union[str, Path], *,
-                   content_type: str=None,
-                   encoding: str='utf8',
-                   proto: Protocol=None,
-                   allow_pickle: bool=False):
+    def parse_file(
+        cls,
+        path: Union[str, Path],
+        *,
+        content_type: str = None,
+        encoding: str = 'utf8',
+        proto: Protocol = None,
+        allow_pickle: bool = False,
+    ):
         obj = load_file(path, proto=proto, content_type=content_type, encoding=encoding, allow_pickle=allow_pickle)
         return cls.parse_obj(obj)
 
@@ -261,7 +286,9 @@ class BaseModel(metaclass=MetaModel):
         m.__setstate__(values)
         return m
 
-    def copy(self, *, include: Set[str]=None, exclude: Set[str]=None, update: Dict[str, Any]=None, deep: bool=False):
+    def copy(
+        self, *, include: Set[str] = None, exclude: Set[str] = None, update: Dict[str, Any] = None, deep: bool = False
+    ):
         """
         Duplicate a model, optionally choose which fields to include, exclude and change.
 
@@ -279,7 +306,7 @@ class BaseModel(metaclass=MetaModel):
             exclude = exclude or set()
             v = {
                 **{k: v for k, v in self.__values__.items() if k not in exclude and (not include or k in include)},
-                **(update or {})
+                **(update or {}),
             }
         if deep:
             v = deepcopy(v)
@@ -295,9 +322,9 @@ class BaseModel(metaclass=MetaModel):
             'type': 'object',
             'properties': (
                 {f.alias: f.schema(by_alias) for f in cls.__fields__.values()}
-                if by_alias else
-                {k: f.schema(by_alias) for k, f in cls.__fields__.items()}
-            )
+                if by_alias
+                else {k: f.schema(by_alias) for k, f in cls.__fields__.items()}
+            ),
         }
 
     @classmethod
@@ -316,6 +343,7 @@ class BaseModel(metaclass=MetaModel):
     @classmethod
     def schema_json(cls, *, by_alias=True, **dumps_kwargs) -> str:
         from .json import pydantic_encoder
+
         return json.dumps(cls.schema(by_alias=by_alias), default=pydantic_encoder, **dumps_kwargs)
 
     @classmethod
@@ -377,10 +405,8 @@ class BaseModel(metaclass=MetaModel):
 
 
 def create_model(
-        model_name: str, *,
-        __config__: Type[BaseConfig]=None,
-        __base__: Type[BaseModel]=None,
-        **field_definitions):
+    model_name: str, *, __config__: Type[BaseConfig] = None, __base__: Type[BaseModel] = None, **field_definitions
+):
     """
     Dynamically create a model.
     :param model_name: name of the created model
@@ -407,9 +433,11 @@ def create_model(
             try:
                 f_annotation, f_value = f_def
             except ValueError as e:
-                raise ConfigError(f'field definitions should either be a tuple of (<type>, <default>) or just a '
-                                  f'default value, unfortunately this means tuples as '
-                                  f'default values are not allowed') from e
+                raise ConfigError(
+                    f'field definitions should either be a tuple of (<type>, <default>) or just a '
+                    f'default value, unfortunately this means tuples as '
+                    f'default values are not allowed'
+                ) from e
         else:
             f_annotation, f_value = None, f_def
         if f_name.startswith('_'):
@@ -423,17 +451,14 @@ def create_model(
                 config=config,
             )
 
-    namespace = {
-        'config': config,
-        '__fields__': fields,
-    }
+    namespace = {'config': config, '__fields__': fields}
     return type(model_name, (__base__,), namespace)
 
 
 _FUNCS = set()
 
 
-def validator(*fields, pre: bool=False, whole: bool=False, always: bool=False, check_fields: bool=True):
+def validator(*fields, pre: bool = False, whole: bool = False, always: bool = False, check_fields: bool = True):
     """
     Decorate methods on the class indicating that they should be used to validate fields
     :param fields: which field(s) the method should be called on
@@ -445,8 +470,10 @@ def validator(*fields, pre: bool=False, whole: bool=False, always: bool=False, c
     if not fields:
         raise ConfigError('validator with no fields specified')
     elif isinstance(fields[0], FunctionType):
-        raise ConfigError("validators should be used with fields and keyword arguments, not bare. "
-                          "E.g. usage should be `@validator('<field_name>', ...)`")
+        raise ConfigError(
+            "validators should be used with fields and keyword arguments, not bare. "
+            "E.g. usage should be `@validator('<field_name>', ...)`"
+        )
 
     def dec(f):
         ref = f.__module__ + '.' + f.__qualname__
@@ -456,6 +483,7 @@ def validator(*fields, pre: bool=False, whole: bool=False, always: bool=False, c
         f_cls = classmethod(f)
         f_cls.__validator_config = fields, Validator(f, pre, whole, always, check_fields)
         return f_cls
+
     return dec
 
 
