@@ -1,9 +1,10 @@
+import re
 from collections import OrderedDict
 from datetime import date, datetime, time, timedelta
 from decimal import Decimal, DecimalException
 from enum import Enum
 from pathlib import Path
-from typing import Any
+from typing import Any, Pattern
 from uuid import UUID
 
 from . import errors
@@ -44,12 +45,7 @@ def bytes_validator(v) -> bytes:
         raise errors.BytesError()
 
 
-BOOL_STRINGS = {
-    '1',
-    'TRUE',
-    'ON',
-    'YES',
-}
+BOOL_STRINGS = {'1', 'TRUE', 'ON', 'YES'}
 
 
 def bool_validator(v) -> bool:
@@ -63,7 +59,7 @@ def bool_validator(v) -> bool:
 
 
 def int_validator(v) -> int:
-    if isinstance(v, int):
+    if not isinstance(v, bool) and isinstance(v, int):
         return v
 
     with change_exception(errors.IntegerError, TypeError, ValueError):
@@ -218,27 +214,29 @@ def make_arbitrary_type_validator(type_):
         if isinstance(v, type_):
             return v
         raise errors.ArbitraryTypeError(expected_arbitrary_type=type_)
+
     return arbitrary_type_validator
 
 
+def pattern_validator(v) -> Pattern:
+    with change_exception(errors.PatternError, re.error):
+        return re.compile(v)
+
+
+pattern_validators = [not_none_validator, str_validator, pattern_validator]
 # order is important here, for example: bool is a subclass of int so has to come first, datetime before date same
 _VALIDATORS = [
     (Enum, [enum_validator]),
-
     (str, [not_none_validator, str_validator, anystr_strip_whitespace, anystr_length_validator]),
     (bytes, [not_none_validator, bytes_validator, anystr_strip_whitespace, anystr_length_validator]),
-
     (bool, [bool_validator]),
     (int, [int_validator]),
     (float, [float_validator]),
-
     (Path, [path_validator]),
-
     (datetime, [parse_datetime]),
     (date, [parse_date]),
     (time, [parse_time]),
     (timedelta, [parse_duration]),
-
     (OrderedDict, [ordered_dict_validator]),
     (dict, [dict_validator]),
     (list, [list_validator]),
@@ -252,6 +250,8 @@ _VALIDATORS = [
 def find_validators(type_, arbitrary_types_allowed=False):
     if type_ is Any:
         return []
+    if type_ is Pattern:
+        return pattern_validators
 
     supertype = _find_supertype(type_)
     if supertype is not None:
